@@ -27,15 +27,16 @@ class InputTextMessageContent(InputMessageContent):
     Represents the content of a text message to be sent as the result of an inline query.
 
     Attributes:
-        message_text (:obj:`str`): Text of the message to be sent, 1-4096 characters.
+        message_text (:obj:`str`): Text of the message to be sent, 1-4096 characters after entities
+            parsing.
         parse_mode (:obj:`str`): Optional. Send Markdown or HTML, if you want Telegram apps to show
             bold, italic, fixed-width text or inline URLs in your bot's message.
         disable_web_page_preview (:obj:`bool`): Optional. Disables link previews for links in the
             sent message.
 
     Args:
-        message_text (:obj:`str`): Text of the message to be sent, 1-4096 characters.  Also found
-            as :attr:`telegram.constants.MAX_MESSAGE_LENGTH`.
+        message_text (:obj:`str`): Text of the message to be sent, 1-4096 characters after entities
+            parsing. Also found as :attr:`telegram.constants.MAX_MESSAGE_LENGTH`.
         parse_mode (:obj:`str`, optional): Send Markdown or HTML, if you want Telegram apps to show
             bold, italic, fixed-width text or inline URLs in your bot's message.
         disable_web_page_preview (:obj:`bool`, optional): Disables link previews for links in the
